@@ -11,7 +11,7 @@ dialogId("sl-v-nechme", "font_big", "Leave me alone. I adore the classic beauty
 
 dialogId("sl-m-sedi", "font_small", "Who is sitting on that chair?")
 
-dialogId("sl-v-feidios", "font_big", "It`s a copy of Feidios` Zeus. One of the seven wonders of the world.")
+dialogId("sl-v-feidios", "font_big", "It’s a copy of Feidios’ Zeus. One of the seven wonders of the world.")
 
 dialogId("sl-m-tehdy", "font_small", "Hmm. It was another age.")
 
@@ -23,6 +23,6 @@ dialogId("sl-v-pust", "font_big", "And now ease it down, carefully.")
 
 dialogId("sl-m-jekot", "", "")
 
-dialogId("sl-v-barbarka", "font_big", "You barbarian! Can`t you be a little bit cautious?!")
+dialogId("sl-v-barbarka", "font_big", "You barbarian! Can’t you be a little bit cautious?!")
 
-dialogId("sl-m-nelibila", "font_small", "I didn`t like this sculpture anyway.")
+dialogId("sl-m-nelibila", "font_small", "I didn’t like this sculpture anyway.")
