@@ -3,7 +3,7 @@ dialogId("disk-v-metrova", "font_big", "Look how much bigger than me it is. It i
 dialogStr("Schau, sie ist viel grösser als ich. Es ist eine Dreieinhalb-Meter-Diskette.")
 
 
-dialogId("disk-m-velka", "font_small", "That`s better. Big plan, big disk. That makes sense.")
+dialogId("disk-m-velka", "font_small", "That’s better. Big plan, big disk. That makes sense.")
 dialogStr("Das ist besser. Grosser Plan, grosse Diskette. Das macht Sinn.")
 
 
