@@ -1,10 +1,8 @@
 dialogId("m-strasidelna", "font_small", "It is a haunted room.")
 dialogStr("Det här är ett hemsökt rum.")
 
-dialogId("v-bojim", "font_big",
-"I fear it will be dificult to move things over this hole.")
-dialogStr(
-"Jag är rädd... att det kommer att bli svårt att flytta saker över hålet.")
+dialogId("v-bojim", "font_big", "I fear it will be dificult to move things over this hole.")
+dialogStr("Jag är rädd... att det kommer att bli svårt att flytta saker över hålet.")
 
 dialogId("s-prejete", "font_green", "Here you are, as you wish.")
 dialogStr("Var så god, som du önskar.")
@@ -12,58 +10,50 @@ dialogStr("Var så god, som du önskar.")
 dialogId("l-halo0", "font_lightgrey", "Is anybody there?")
 dialogStr("Är det någon här?")
 
-dialogId("l-halo1", "font_lightgrey", "Who are there?")
+dialogId("l-halo1", "font_lightgrey", "Who is there?")
 dialogStr("Vem är där?")
 
 dialogId("l-halo2", "font_lightgrey", "I think, the receiver does not work.")
 dialogStr("Jag tror att mottagaren inte fungerar.")
 
-dialogId("l-dejte0", "font_lightgrey",
-         "Put it back immediately, the indian headdress is mine.")
+dialogId("l-dejte0", "font_lightgrey", "Put it back immediately, the indian headdress is mine.")
 dialogStr("Lägg tillbaks den genast, indianskruden är min!")
 
 dialogId("l-dejte1", "font_lightgrey", "Put it back immediately, it is mine!")
 dialogStr("Lägg tillbaks den genast, den är min!")
 
-dialogId("l-dejte2", "font_lightgrey",
-         "O O O O, I am indian. Put it back immediately!")
+dialogId("l-dejte2", "font_lightgrey", "O O O O, I am indian. Put it back immediately!")
 dialogStr("O O O O, jag är indian. Lägg tillbaks den genast!")
 
 dialogId("l-dejte3", "font_lightgrey", "O O O O, put it back immediately!")
 dialogStr("O O O O, lägg tillbaks den genast")
 
-dialogId("l-vinnetou", "font_lightgrey",
-         "Where are you pushing me? I am famous Vinnetou!")
+dialogId("l-vinnetou", "font_lightgrey", "Where are you pushing me? I am famous Vinnetou!")
 dialogStr("Vart knuffar du mig? Jag är den berömde Vinnetou!")
 
-dialogId("m-nedame0", "font_small",
-         "Sorry, we need it necessarily.")
+dialogId("m-nedame0", "font_small", "Sorry, we need it necessarily.")
 dialogStr("Förlåt, vi måste ha den.")
 
-dialogId("v-nedame0", "font_big",
-"How can it be yours, if you are not indian?")
+dialogId("v-nedame0", "font_big", "How can it be yours, if you are not indian?")
 dialogStr("Hur kan den vara din, om du inte är indian?")
 
-dialogId("m-nedame1", "font_small", "You can’t be indian because you are not red?")
+dialogId("m-nedame1", "font_small", "You can’t be an indian because you are not red.")
 dialogStr("Du kan inte vara indian, för du är inte röd?")
 
 dialogId("v-nedame1", "font_big", "I can’t demur anything.")
 dialogStr("Jag kan inte invända något.")
 
-dialogId("v-neber", "font_big", "Player, if you are an indian, don’t perceive as an discrimination please.")
-dialogStr(
-"Spelare, om du är en indian, se det inte som diskriminering, snälla.")
+dialogId("v-neber", "font_big", "Player, if you are an indian, don’t perceive it as an discrimination please.")
+dialogStr("Spelare, om du är en indian, se det inte som diskriminering, snälla.")
 
-dialogId("m-sluchatko", "font_small", "It may be magic receiver.")
+dialogId("m-sluchatko", "font_small", "It may be a magic receiver.")
 dialogStr("Det kanske är en magisk mottagare.")
 
 dialogId("v-zkus", "font_big", "Try it.")
 dialogStr("Testa den.")
 
-dialogId("m-zmizet", "font_small",
-         "Hello, I wish to disappear the steel near exit?")
+dialogId("m-zmizet", "font_small", "Hello, I wish to disappear the steel near exit?")
 dialogStr("Hallå jag vill att stålet vid utgången försvinner?")
 
-dialogId("v-vratte", "font_big",
-         "Put it back, it should be solved by player, not by ourself.")
+dialogId("v-vratte", "font_big", "Put it back, it should be solved by player, not by ourself.")
 dialogStr("Ställ tillbaka den, det borde lösas av spelaren, inte av oss själva.")
