@@ -7,7 +7,7 @@ dialogId("sch-v-lastura", "font_big", "It’s some kind of shell. We’ll probab
 dialogStr("Es ist eine Art Muschel. Wir müssen sie wahrscheinlich wieder die Treppe hochschieben.")
 
 
-dialogId("sch-v-setkani", "font_big", "I can see it now: 'Shell Meets Flowerpot’. That’s almost like an iron and a sewing machine meeting on an operating table.")
+dialogId("sch-v-setkani", "font_big", "I can see it now: ‘Shell Meets Flowerpot’. That’s almost like an iron and a sewing machine meeting on an operating table.")
 dialogStr("Das ist es: \"Muschel trifft Blumentopf\". Das ist ja fast so, als wenn sich ein Bügeleisen und eine Nähmaschine auf einem Operationstisch treffen.")
 
 
